@@ -27,47 +27,44 @@ pip install cloudcomponents.cdk-dependency-check
 ## How to use
 
 ```python
-import { Construct, Stack, StackProps } from '@aws-cdk/core';
-import { Repository } from '@aws-cdk/aws-codecommit';
-import { Schedule } from '@aws-cdk/aws-events';
-import { SnsTopic } from '@aws-cdk/aws-events-targets';
-import { Bucket } from '@aws-cdk/aws-s3';
-import { Topic } from '@aws-cdk/aws-sns';
-import { EmailSubscription } from '@aws-cdk/aws-sns-subscriptions';
 import { CodeCommitDependencyCheck } from '@cloudcomponents/cdk-dependency-check';
+import { Stack, StackProps } from 'aws-cdk-lib';
+import { Repository } from 'aws-cdk-lib/aws-codecommit';
+import { Schedule } from 'aws-cdk-lib/aws-events';
+import { SnsTopic } from 'aws-cdk-lib/aws-events-targets';
+import { Bucket } from 'aws-cdk-lib/aws-s3';
+import { Topic } from 'aws-cdk-lib/aws-sns';
+import { EmailSubscription } from 'aws-cdk-lib/aws-sns-subscriptions';
+import { Construct } from 'constructs';
 
 export class DependencyCheckStack extends Stack {
   constructor(scope: Construct, id: string, props?: StackProps) {
     super(scope, id, props);
 
-    const repository = Repository.fromRepositoryName(
-      this,
-      'Repository',
-      process.env.REPOSITORY_NAME as string,
-    );
+    if (typeof process.env.REPOSITORY_NAME === 'undefined') {
+      throw new Error('environment variable REPOSITORY_NAME undefined');
+    }
+
+    const repository = Repository.fromRepositoryName(this, 'Repository', process.env.REPOSITORY_NAME);
 
     const reportsBucket = new Bucket(this, 'Bucket');
 
     // The following example runs a task every day at 4am
-    const check = new CodeCommitDependencyCheck(
-      this,
-      'CodeCommitDependencyCheck',
-      {
-        repository,
-        reportsBucket,
-        preCheckCommand: 'npm i',
-        schedule: Schedule.cron({
-          minute: '0',
-          hour: '4',
-        }),
-      },
-    );
+    const check = new CodeCommitDependencyCheck(this, 'CodeCommitDependencyCheck', {
+      repository,
+      reportsBucket,
+      preCheckCommand: 'npm i',
+      schedule: Schedule.cron({
+        minute: '0',
+        hour: '4',
+      }),
+    });
 
     const checkTopic = new Topic(this, 'CheckTopic');
 
-    checkTopic.addSubscription(
-      new EmailSubscription(process.env.DEVSECOPS_TEAM_EMAIL as string),
-    );
+    if (process.env.DEVSECOPS_TEAM_EMAIL) {
+      checkTopic.addSubscription(new EmailSubscription(process.env.DEVSECOPS_TEAM_EMAIL));
+    }
 
     check.onCheckStarted('started', {
       target: new SnsTopic(checkTopic),
@@ -129,17 +126,17 @@ import aws_cdk.aws_codebuild
 import aws_cdk.aws_codecommit
 import aws_cdk.aws_events
 import aws_cdk.aws_s3
-import aws_cdk.core
+import constructs
 
 
 class CodeCommitDependencyCheck(
-    aws_cdk.core.Construct,
+    constructs.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cloudcomponents/cdk-dependency-check.CodeCommitDependencyCheck",
 ):
     def __init__(
         self,
-        scope: aws_cdk.core.Construct,
+        scope: constructs.Construct,
         id: builtins.str,
         *,
         repository: aws_cdk.aws_codecommit.IRepository,
